pub fn diff(migration_graph: &SchemaGraph, live: &LiveSchema) -> DriftReportExpand description
Compare the schema graph inferred from migration files against the live database snapshot.
pub fn diff(migration_graph: &SchemaGraph, live: &LiveSchema) -> DriftReportCompare the schema graph inferred from migration files against the live database snapshot.