pub struct ImpactScanner { /* private fields */ }Implementations
Sourceimpl ImpactScanner
impl ImpactScanner
Sourcepub fn new(tables: Vec<String>, columns: Vec<String>) -> Self
pub fn new(tables: Vec<String>, columns: Vec<String>) -> Self
Create a scanner that skips identifiers shorter than 4 characters to avoid false positives (B-03 fix).
Use [new_scan_short] if you need to include short identifiers.
Sourcepub fn new_scan_short(tables: Vec<String>, columns: Vec<String>) -> Self
pub fn new_scan_short(tables: Vec<String>, columns: Vec<String>) -> Self
Create a scanner that includes all short identifiers (opt-in via --scan-short-names).
Sourcepub fn scan(&self, root_dir: &Path) -> ImpactReport
pub fn scan(&self, root_dir: &Path) -> ImpactReport
Walk root_dir recursively, scan all source files in parallel, return
an ImpactReport.